@@ -23,15 +23,15 @@
 #include <vdr/plugin.h>
 #include "calllist.h"
 #include "fonbuchmanager.h"
+#include "fritztools.h"
 #include "fritzlistener.h"
 #include "fritzfonbuch.h"
-#include "i18n.h"
 #include "setup.h"
 #include "menu.h"
 
-static const char *VERSION        = "0.0.9";
-static const char *DESCRIPTION    = "Fritz!Box Plugin for AVM Fritz!Box";
-static const char *MAINMENUENTRY  = "Fritz!Box phone book";
+static const char *VERSION        = "1.0.0";
+static const char *DESCRIPTION    = trNOOP("Fritz!Box Plugin for AVM Fritz!Box");
+static const char *MAINMENUENTRY  = trNOOP("Fritz!Box phone book");
 
 class cPluginFritzbox : public cPlugin {
 private:
@@ -42,7 +42,7 @@ public:
 	cPluginFritzbox(void);
 	virtual ~cPluginFritzbox();
 	virtual const char *Version(void) { return VERSION; }
-	virtual const char *Description(void) { return DESCRIPTION; }
+	virtual const char *Description(void) { return tr(DESCRIPTION); }
 	virtual const char *CommandLineHelp(void);
 	virtual bool ProcessArgs(int argc, char *argv[]);
 	virtual bool Initialize(void);
@@ -87,20 +87,17 @@ bool cPluginFritzbox::ProcessArgs(int argc, char *argv[])
 
 bool cPluginFritzbox::Initialize(void)
 {
-	// Initialize any background activities the plugin shall perform.
 	return true;
 }
 
 bool cPluginFritzbox::Start(void)
 {
 	// Start any background activities the plugin shall perform.
-#if VDRVERSNUM < 10507	
-	RegisterI18n(Phrases);
-#endif
 	fonbuch = cFonbuchManager::GetFonbuch();
 	callList = new cCallList();
 	listener = new cFritzListener(fritzboxConfig.url, PORT_MONITOR, fonbuch, callList);
-	listener->Start();
+	if (listener)
+		listener->Start();
 	return true;
 }
 
@@ -108,7 +105,13 @@ bool cPluginFritzbox::Start(void)
 void cPluginFritzbox::Stop(void)
 {
 	// Stop any background activities the plugin shall perform.
-	delete listener;
+	if (listener)
+		delete listener;
+	if (callList)
+		delete callList;
+	if (fonbuch)
+		delete fonbuch;
+		
 }
 
 void cPluginFritzbox::Housekeeping(void)
@@ -118,9 +121,11 @@ void cPluginFritzbox::Housekeeping(void)
 
 void cPluginFritzbox::MainThreadHook(void)
 {
-	char *msg = listener->GetMessage();
-	if (msg) {
-		Skins.Message(mtInfo, msg);
+	if (listener) {
+		char *msg = listener->GetMessage();
+		if (msg) {
+			Skins.Message(mtInfo, msg);
+		}
 	}
 }
 
