@@ -35,6 +35,7 @@ class cMenuSetupFritzbox : public cMenuSetupPage
 private:
 	char *url;
 	char *password;
+//	char *countryCode;
 	int muteOnCall;
 	int pauseOnCall;
 	int showNumber;
@@ -81,6 +82,8 @@ public:
 	bool SetupParse(const char *Name, const char *Value);
 	std::string url;
 	std::string password;
+	std::string countryCode;
+	std::string regionCode;
 	int muteOnCall;
 	int pauseOnCall;
 	int showNumber;
